==> haskell-text-icu-0.7.0.1-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-text-icu.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-icu
version: 0.7.0.1
id: text-icu-0.7.0.1-GlaGNjy1nPYCIvsW6Wh4VM
key: text-icu-0.7.0.1-GlaGNjy1nPYCIvsW6Wh4VM
license: BSD3
copyright: 2009-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/text-icu
synopsis: Bindings to the ICU library
description:
    Haskell bindings to the International Components for Unicode (ICU)
    libraries.  These libraries provide robust and full-featured Unicode
    services on a wide variety of platforms.
    .
    Features include:
    .
    * Both pure and impure bindings, to allow for fine control over efficiency
    and ease of use.
    .
    * Breaking of strings on character, word, sentence, and line boundaries.
    .
    * Access to the Unicode Character Database (UCD) of character metadata.
    .
    * String collation functions, for locales where the conventions for
    lexicographic ordering differ from the simple numeric ordering of
    character codes.
    .
    * Character set conversion functions, allowing conversion between
    Unicode and over 220 character encodings.
    .
    * Unicode normalization.  (When implementations keep strings in a
    normalized form, they can be assured that equivalent strings have a
    unique binary representation.)
    .
    * Regular expression search and replace.
category: Data, Text
exposed: True
indefinite: False
exposed-modules:
    Data.Text.ICU Data.Text.ICU.Break Data.Text.ICU.Char
    Data.Text.ICU.Collate Data.Text.ICU.Convert Data.Text.ICU.Error
    Data.Text.ICU.Normalize Data.Text.ICU.Regex Data.Text.ICU.Types
hidden-modules: Data.Text.ICU.Break.Pure Data.Text.ICU.Break.Types
                Data.Text.ICU.Collate.Internal Data.Text.ICU.Collate.Pure
                Data.Text.ICU.Convert.Internal Data.Text.ICU.Error.Internal
                Data.Text.ICU.Internal Data.Text.ICU.Iterator
                Data.Text.ICU.Normalize.Internal Data.Text.ICU.Regex.Internal
                Data.Text.ICU.Regex.Pure Data.Text.ICU.Text
abi: 74db6350b3175e031762f379586e3723
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/text-icu-0.7.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/text-icu-0.7.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/text-icu-0.7.0.1
hs-libraries: HStext-icu-0.7.0.1-GlaGNjy1nPYCIvsW6Wh4VM
extra-libraries:
    icuuc icui18n icudata
depends:
    base-4.10.1.0 bytestring-0.10.8.2 deepseq-1.4.3.0
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
haddock-interfaces: /usr/share/doc/haskell-text-icu/html/text-icu.haddock
haddock-html: /usr/share/doc/haskell-text-icu/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-icu-0.7.0.1-19-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-text-icu.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-icu
version: 0.7.0.1
id: text-icu-0.7.0.1-GQ0DM6OBTErByT1EmU06SY
key: text-icu-0.7.0.1-GQ0DM6OBTErByT1EmU06SY
license: BSD-3-Clause
copyright: 2009-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/text-icu
synopsis: Bindings to the ICU library
description:
    Haskell bindings to the International Components for Unicode (ICU)
    libraries.  These libraries provide robust and full-featured Unicode
    services on a wide variety of platforms.
    .
    Features include:
    .
    * Both pure and impure bindings, to allow for fine control over efficiency
    and ease of use.
    .
    * Breaking of strings on character, word, sentence, and line boundaries.
    .
    * Access to the Unicode Character Database (UCD) of character metadata.
    .
    * String collation functions, for locales where the conventions for
    lexicographic ordering differ from the simple numeric ordering of
    character codes.
    .
    * Character set conversion functions, allowing conversion between
    Unicode and over 220 character encodings.
    .
    * Unicode normalization.  (When implementations keep strings in a
    normalized form, they can be assured that equivalent strings have a
    unique binary representation.)
    .
    * Regular expression search and replace.
category: Data, Text
abi: 146441e6e65cb12937d91163213f0ec6
exposed: True
exposed-modules:
    Data.Text.ICU Data.Text.ICU.Break Data.Text.ICU.Char
    Data.Text.ICU.Collate Data.Text.ICU.Convert Data.Text.ICU.Error
    Data.Text.ICU.Normalize Data.Text.ICU.Regex Data.Text.ICU.Types
hidden-modules: Data.Text.ICU.Break.Pure Data.Text.ICU.Break.Types
                Data.Text.ICU.Collate.Internal Data.Text.ICU.Collate.Pure
                Data.Text.ICU.Convert.Internal Data.Text.ICU.Error.Internal
                Data.Text.ICU.Internal Data.Text.ICU.Iterator
                Data.Text.ICU.Normalize.Internal Data.Text.ICU.Regex.Internal
                Data.Text.ICU.Regex.Pure Data.Text.ICU.Text
import-dirs: /usr/lib/ghc-8.4.3/site-local/text-icu-0.7.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/text-icu-0.7.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/text-icu-0.7.0.1
hs-libraries: HStext-icu-0.7.0.1-GQ0DM6OBTErByT1EmU06SY
extra-libraries:
    icuuc icui18n icudata
depends:
    base-4.11.1.0 bytestring-0.10.8.2 deepseq-1.4.3.0 text-1.2.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
haddock-interfaces: /usr/share/doc/haskell-text-icu/html/text-icu.haddock
haddock-html: /usr/share/doc/haskell-text-icu/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
